==> syslog-ng_1.9.11.orig.tar.gz: syslog-ng-1.9.11.orig/src/cfg-grammar.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     KW_SOURCE = 258,
     KW_DESTINATION = 259,
     KW_LOG = 260,
     KW_OPTIONS = 261,
     KW_FILTER = 262,
     KW_INTERNAL = 263,
     KW_FILE = 264,
     KW_PIPE = 265,
     KW_UNIX_STREAM = 266,
     KW_UNIX_DGRAM = 267,
     KW_TCP = 268,
     KW_UDP = 269,
     KW_TCP6 = 270,
     KW_UDP6 = 271,
     KW_USER = 272,
     KW_DOOR = 273,
     KW_SUN_STREAMS = 274,
     KW_PROGRAM = 275,
     KW_FSYNC = 276,
     KW_MARK_FREQ = 277,
     KW_STATS_FREQ = 278,
     KW_FLUSH_LINES = 279,
     KW_FLUSH_TIMEOUT = 280,
     KW_LOG_MSG_SIZE = 281,
     KW_FILE_TEMPLATE = 282,
     KW_PROTO_TEMPLATE = 283,
     KW_CHAIN_HOSTNAMES = 284,
     KW_NORMALIZE_HOSTNAMES = 285,
     KW_KEEP_HOSTNAME = 286,
     KW_CHECK_HOSTNAME = 287,
     KW_BAD_HOSTNAME = 288,
     KW_KEEP_TIMESTAMP = 289,
     KW_USE_DNS = 290,
     KW_USE_FQDN = 291,
     KW_DNS_CACHE = 292,
     KW_DNS_CACHE_SIZE = 293,
     KW_DNS_CACHE_EXPIRE = 294,
     KW_DNS_CACHE_EXPIRE_FAILED = 295,
     KW_TZ_CONVERT = 296,
     KW_TS_FORMAT = 297,
     KW_FRAC_DIGITS = 298,
     KW_LOG_FIFO_SIZE = 299,
     KW_LOG_FETCH_LIMIT = 300,
     KW_LOG_IW_SIZE = 301,
     KW_LOG_PREFIX = 302,
     KW_FLAGS = 303,
     KW_CATCHALL = 304,
     KW_FALLBACK = 305,
     KW_FINAL = 306,
     KW_FLOW_CONTROL = 307,
     KW_PAD_SIZE = 308,
     KW_TIME_ZONE = 309,
     KW_RECV_TIME_ZONE = 310,
     KW_SEND_TIME_ZONE = 311,
     KW_TIME_REOPEN = 312,
     KW_TIME_REAP = 313,
     KW_TIME_SLEEP = 314,
     KW_TMPL_ESCAPE = 315,
     KW_OPTIONAL = 316,
     KW_CREATE_DIRS = 317,
     KW_OWNER = 318,
     KW_GROUP = 319,
     KW_PERM = 320,
     KW_DIR_OWNER = 321,
     KW_DIR_GROUP = 322,
     KW_DIR_PERM = 323,
     KW_TEMPLATE = 324,
     KW_TEMPLATE_ESCAPE = 325,
     KW_FOLLOW_FREQ = 326,
     KW_KEEP_ALIVE = 327,
     KW_MAX_CONNECTIONS = 328,
     KW_LOCALIP = 329,
     KW_IP = 330,
     KW_LOCALPORT = 331,
     KW_PORT = 332,
     KW_DESTPORT = 333,
     KW_IP_TTL = 334,
     KW_SO_BROADCAST = 335,
     KW_IP_TOS = 336,
     KW_SO_SNDBUF = 337,
     KW_SO_RCVBUF = 338,
     KW_USE_TIME_RECVD = 339,
     KW_FACILITY = 340,
     KW_LEVEL = 341,
     KW_HOST = 342,
     KW_MATCH = 343,
     KW_NETMASK = 344,
     KW_YES = 345,
     KW_NO = 346,
     KW_REQUIRED = 347,
     KW_ALLOW = 348,
     KW_DENY = 349,
     KW_GC_IDLE_THRESHOLD = 350,
     KW_GC_BUSY_THRESHOLD = 351,
     KW_COMPRESS = 352,
     KW_MAC = 353,
     KW_AUTH = 354,
     KW_ENCRYPT = 355,
     DOTDOT = 356,
     IDENTIFIER = 357,
     NUMBER = 358,
     STRING = 359,
     KW_OR = 360,
     KW_AND = 361,
     KW_NOT = 362
   };
#endif
#define KW_SOURCE 258
#define KW_DESTINATION 259
#define KW_LOG 260
#define KW_OPTIONS 261
#define KW_FILTER 262
#define KW_INTERNAL 263
#define KW_FILE 264
#define KW_PIPE 265
#define KW_UNIX_STREAM 266
#define KW_UNIX_DGRAM 267
#define KW_TCP 268
#define KW_UDP 269
#define KW_TCP6 270
#define KW_UDP6 271
#define KW_USER 272
#define KW_DOOR 273
#define KW_SUN_STREAMS 274
#define KW_PROGRAM 275
#define KW_FSYNC 276
#define KW_MARK_FREQ 277
#define KW_STATS_FREQ 278
#define KW_FLUSH_LINES 279
#define KW_FLUSH_TIMEOUT 280
#define KW_LOG_MSG_SIZE 281
#define KW_FILE_TEMPLATE 282
#define KW_PROTO_TEMPLATE 283
#define KW_CHAIN_HOSTNAMES 284
#define KW_NORMALIZE_HOSTNAMES 285
#define KW_KEEP_HOSTNAME 286
#define KW_CHECK_HOSTNAME 287
#define KW_BAD_HOSTNAME 288
#define KW_KEEP_TIMESTAMP 289
#define KW_USE_DNS 290
#define KW_USE_FQDN 291
#define KW_DNS_CACHE 292
#define KW_DNS_CACHE_SIZE 293
#define KW_DNS_CACHE_EXPIRE 294
#define KW_DNS_CACHE_EXPIRE_FAILED 295
#define KW_TZ_CONVERT 296
#define KW_TS_FORMAT 297
#define KW_FRAC_DIGITS 298
#define KW_LOG_FIFO_SIZE 299
#define KW_LOG_FETCH_LIMIT 300
#define KW_LOG_IW_SIZE 301
#define KW_LOG_PREFIX 302
#define KW_FLAGS 303
#define KW_CATCHALL 304
#define KW_FALLBACK 305
#define KW_FINAL 306
#define KW_FLOW_CONTROL 307
#define KW_PAD_SIZE 308
#define KW_TIME_ZONE 309
#define KW_RECV_TIME_ZONE 310
#define KW_SEND_TIME_ZONE 311
#define KW_TIME_REOPEN 312
#define KW_TIME_REAP 313
#define KW_TIME_SLEEP 314
#define KW_TMPL_ESCAPE 315
#define KW_OPTIONAL 316
#define KW_CREATE_DIRS 317
#define KW_OWNER 318
#define KW_GROUP 319
#define KW_PERM 320
#define KW_DIR_OWNER 321
#define KW_DIR_GROUP 322
#define KW_DIR_PERM 323
#define KW_TEMPLATE 324
#define KW_TEMPLATE_ESCAPE 325
#define KW_FOLLOW_FREQ 326
#define KW_KEEP_ALIVE 327
#define KW_MAX_CONNECTIONS 328
#define KW_LOCALIP 329
#define KW_IP 330
#define KW_LOCALPORT 331
#define KW_PORT 332
#define KW_DESTPORT 333
#define KW_IP_TTL 334
#define KW_SO_BROADCAST 335
#define KW_IP_TOS 336
#define KW_SO_SNDBUF 337
#define KW_SO_RCVBUF 338
#define KW_USE_TIME_RECVD 339
#define KW_FACILITY 340
#define KW_LEVEL 341
#define KW_HOST 342
#define KW_MATCH 343
#define KW_NETMASK 344
#define KW_YES 345
#define KW_NO 346
#define KW_REQUIRED 347
#define KW_ALLOW 348
#define KW_DENY 349
#define KW_GC_IDLE_THRESHOLD 350
#define KW_GC_BUSY_THRESHOLD 351
#define KW_COMPRESS 352
#define KW_MAC 353
#define KW_AUTH 354
#define KW_ENCRYPT 355
#define DOTDOT 356
#define IDENTIFIER 357
#define NUMBER 358
#define STRING 359
#define KW_OR 360
#define KW_AND 361
#define KW_NOT 362




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 43 "/home/bazsi/zwa/work/syslog-ng-2.0/syslog-ng/src/cfg-grammar.y"
typedef union YYSTYPE {
	guint num;
	char *cptr;
	void *ptr;
	FilterExprNode *node;
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 258 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> syslog-ng_2.0rc1.orig.tar.gz: syslog-ng-2.0rc1/src/cfg-grammar.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     KW_SOURCE = 258,
     KW_DESTINATION = 259,
     KW_LOG = 260,
     KW_OPTIONS = 261,
     KW_FILTER = 262,
     KW_INTERNAL = 263,
     KW_FILE = 264,
     KW_PIPE = 265,
     KW_UNIX_STREAM = 266,
     KW_UNIX_DGRAM = 267,
     KW_TCP = 268,
     KW_UDP = 269,
     KW_TCP6 = 270,
     KW_UDP6 = 271,
     KW_USER = 272,
     KW_DOOR = 273,
     KW_SUN_STREAMS = 274,
     KW_PROGRAM = 275,
     KW_FSYNC = 276,
     KW_MARK_FREQ = 277,
     KW_STATS_FREQ = 278,
     KW_FLUSH_LINES = 279,
     KW_FLUSH_TIMEOUT = 280,
     KW_LOG_MSG_SIZE = 281,
     KW_FILE_TEMPLATE = 282,
     KW_PROTO_TEMPLATE = 283,
     KW_CHAIN_HOSTNAMES = 284,
     KW_NORMALIZE_HOSTNAMES = 285,
     KW_KEEP_HOSTNAME = 286,
     KW_CHECK_HOSTNAME = 287,
     KW_BAD_HOSTNAME = 288,
     KW_KEEP_TIMESTAMP = 289,
     KW_USE_DNS = 290,
     KW_USE_FQDN = 291,
     KW_DNS_CACHE = 292,
     KW_DNS_CACHE_SIZE = 293,
     KW_DNS_CACHE_EXPIRE = 294,
     KW_DNS_CACHE_EXPIRE_FAILED = 295,
     KW_TZ_CONVERT = 296,
     KW_TS_FORMAT = 297,
     KW_FRAC_DIGITS = 298,
     KW_LOG_FIFO_SIZE = 299,
     KW_LOG_FETCH_LIMIT = 300,
     KW_LOG_IW_SIZE = 301,
     KW_LOG_PREFIX = 302,
     KW_FLAGS = 303,
     KW_CATCHALL = 304,
     KW_FALLBACK = 305,
     KW_FINAL = 306,
     KW_FLOW_CONTROL = 307,
     KW_PAD_SIZE = 308,
     KW_TIME_ZONE = 309,
     KW_RECV_TIME_ZONE = 310,
     KW_SEND_TIME_ZONE = 311,
     KW_TIME_REOPEN = 312,
     KW_TIME_REAP = 313,
     KW_TIME_SLEEP = 314,
     KW_TMPL_ESCAPE = 315,
     KW_OPTIONAL = 316,
     KW_CREATE_DIRS = 317,
     KW_OWNER = 318,
     KW_GROUP = 319,
     KW_PERM = 320,
     KW_DIR_OWNER = 321,
     KW_DIR_GROUP = 322,
     KW_DIR_PERM = 323,
     KW_TEMPLATE = 324,
     KW_TEMPLATE_ESCAPE = 325,
     KW_FOLLOW_FREQ = 326,
     KW_KEEP_ALIVE = 327,
     KW_MAX_CONNECTIONS = 328,
     KW_LOCALIP = 329,
     KW_IP = 330,
     KW_LOCALPORT = 331,
     KW_PORT = 332,
     KW_DESTPORT = 333,
     KW_IP_TTL = 334,
     KW_SO_BROADCAST = 335,
     KW_IP_TOS = 336,
     KW_SO_SNDBUF = 337,
     KW_SO_RCVBUF = 338,
     KW_USE_TIME_RECVD = 339,
     KW_FACILITY = 340,
     KW_LEVEL = 341,
     KW_HOST = 342,
     KW_MATCH = 343,
     KW_NETMASK = 344,
     KW_YES = 345,
     KW_NO = 346,
     KW_REQUIRED = 347,
     KW_ALLOW = 348,
     KW_DENY = 349,
     KW_GC_IDLE_THRESHOLD = 350,
     KW_GC_BUSY_THRESHOLD = 351,
     KW_COMPRESS = 352,
     KW_MAC = 353,
     KW_AUTH = 354,
     KW_ENCRYPT = 355,
     DOTDOT = 356,
     IDENTIFIER = 357,
     NUMBER = 358,
     STRING = 359,
     KW_OR = 360,
     KW_AND = 361,
     KW_NOT = 362
   };
#endif
/* Tokens.  */
#define KW_SOURCE 258
#define KW_DESTINATION 259
#define KW_LOG 260
#define KW_OPTIONS 261
#define KW_FILTER 262
#define KW_INTERNAL 263
#define KW_FILE 264
#define KW_PIPE 265
#define KW_UNIX_STREAM 266
#define KW_UNIX_DGRAM 267
#define KW_TCP 268
#define KW_UDP 269
#define KW_TCP6 270
#define KW_UDP6 271
#define KW_USER 272
#define KW_DOOR 273
#define KW_SUN_STREAMS 274
#define KW_PROGRAM 275
#define KW_FSYNC 276
#define KW_MARK_FREQ 277
#define KW_STATS_FREQ 278
#define KW_FLUSH_LINES 279
#define KW_FLUSH_TIMEOUT 280
#define KW_LOG_MSG_SIZE 281
#define KW_FILE_TEMPLATE 282
#define KW_PROTO_TEMPLATE 283
#define KW_CHAIN_HOSTNAMES 284
#define KW_NORMALIZE_HOSTNAMES 285
#define KW_KEEP_HOSTNAME 286
#define KW_CHECK_HOSTNAME 287
#define KW_BAD_HOSTNAME 288
#define KW_KEEP_TIMESTAMP 289
#define KW_USE_DNS 290
#define KW_USE_FQDN 291
#define KW_DNS_CACHE 292
#define KW_DNS_CACHE_SIZE 293
#define KW_DNS_CACHE_EXPIRE 294
#define KW_DNS_CACHE_EXPIRE_FAILED 295
#define KW_TZ_CONVERT 296
#define KW_TS_FORMAT 297
#define KW_FRAC_DIGITS 298
#define KW_LOG_FIFO_SIZE 299
#define KW_LOG_FETCH_LIMIT 300
#define KW_LOG_IW_SIZE 301
#define KW_LOG_PREFIX 302
#define KW_FLAGS 303
#define KW_CATCHALL 304
#define KW_FALLBACK 305
#define KW_FINAL 306
#define KW_FLOW_CONTROL 307
#define KW_PAD_SIZE 308
#define KW_TIME_ZONE 309
#define KW_RECV_TIME_ZONE 310
#define KW_SEND_TIME_ZONE 311
#define KW_TIME_REOPEN 312
#define KW_TIME_REAP 313
#define KW_TIME_SLEEP 314
#define KW_TMPL_ESCAPE 315
#define KW_OPTIONAL 316
#define KW_CREATE_DIRS 317
#define KW_OWNER 318
#define KW_GROUP 319
#define KW_PERM 320
#define KW_DIR_OWNER 321
#define KW_DIR_GROUP 322
#define KW_DIR_PERM 323
#define KW_TEMPLATE 324
#define KW_TEMPLATE_ESCAPE 325
#define KW_FOLLOW_FREQ 326
#define KW_KEEP_ALIVE 327
#define KW_MAX_CONNECTIONS 328
#define KW_LOCALIP 329
#define KW_IP 330
#define KW_LOCALPORT 331
#define KW_PORT 332
#define KW_DESTPORT 333
#define KW_IP_TTL 334
#define KW_SO_BROADCAST 335
#define KW_IP_TOS 336
#define KW_SO_SNDBUF 337
#define KW_SO_RCVBUF 338
#define KW_USE_TIME_RECVD 339
#define KW_FACILITY 340
#define KW_LEVEL 341
#define KW_HOST 342
#define KW_MATCH 343
#define KW_NETMASK 344
#define KW_YES 345
#define KW_NO 346
#define KW_REQUIRED 347
#define KW_ALLOW 348
#define KW_DENY 349
#define KW_GC_IDLE_THRESHOLD 350
#define KW_GC_BUSY_THRESHOLD 351
#define KW_COMPRESS 352
#define KW_MAC 353
#define KW_AUTH 354
#define KW_ENCRYPT 355
#define DOTDOT 356
#define IDENTIFIER 357
#define NUMBER 358
#define STRING 359
#define KW_OR 360
#define KW_AND 361
#define KW_NOT 362




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 43 "/home/bazsi/zwa/work/syslog-ng-2.0/syslog-ng/src/cfg-grammar.y"
typedef union YYSTYPE {
	guint num;
	char *cptr;
	void *ptr;
	FilterExprNode *node;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 259 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
